@@ -467,7 +467,6 @@ static int decode_bzip2(struct terminal *term, struct cache_entry *ce, int *errp
 #endif
 
 #ifdef HAVE_LZMA
-#undef internal
 #include <lzma.h>
 #define internal internal_
 static int decode_lzma(struct terminal *term, struct cache_entry *ce, int *errp)
@@ -755,7 +754,7 @@ int get_file_by_term(struct terminal *term, struct cache_entry *ce, unsigned cha
 	}
 	uncompressed:
 	if ((e = defrag_entry(ce)) < 0) {
-		unsigned char *msg = get_err_msg(e);
+		unsigned char *msg = get_err_msg(e, term);
 		if (display_error(term, TEXT_(T_ERROR), errp)) {
 			unsigned char *u = display_url(term, ce->url, 1);
 			msg_box(term, getml(u, NULL), TEXT_(T_ERROR), AL_CENTER, TEXT_(T_ERROR_LOADING), cast_uchar " ", u, cast_uchar ":\n\n", msg, MSG_BOX_END, NULL, 1, TEXT_(T_CANCEL), msg_box_null, B_ENTER | B_ESC);
@@ -783,7 +782,7 @@ void free_decompressed_data(struct cache_entry *e)
 {
 	if (e->decompressed) {
 		if (decompressed_cache_size < e->decompressed_len)
-			internal("free_decompressed_data: decompressed_cache_size underflow %lu, %lu", (unsigned long)decompressed_cache_size, (unsigned long)e->decompressed_len);
+			internal_error("free_decompressed_data: decompressed_cache_size underflow %lu, %lu", (unsigned long)decompressed_cache_size, (unsigned long)e->decompressed_len);
 		decompressed_cache_size -= e->decompressed_len;
 		e->decompressed_len = 0;
 		mem_free(e->decompressed);
@@ -803,7 +802,7 @@ void add_compress_methods(unsigned char **s, int *l)
 #ifdef zlib_version
 		add_to_str(s, l, cast_uchar " (");
 		add_to_str(s, l, (unsigned char *)zlib_version);
-		add_to_str(s, l, cast_uchar ")");
+		add_chr_to_str(s, l, ')');
 #endif
 	}
 #endif
@@ -814,11 +813,11 @@ void add_compress_methods(unsigned char **s, int *l)
 		add_to_str(s, l, cast_uchar "BROTLI");
 		add_to_str(s, l, cast_uchar " (");
 		add_num_to_str(s, l, bv >> 24);
-		add_to_str(s, l, cast_uchar ".");
+		add_chr_to_str(s, l, '.');
 		add_num_to_str(s, l, (bv >> 12) & 0xfff);
-		add_to_str(s, l, cast_uchar ".");
+		add_chr_to_str(s, l, '.');
 		add_num_to_str(s, l, bv & 0xfff);
-		add_to_str(s, l, cast_uchar ")");
+		add_chr_to_str(s, l, ')');
 	}
 #endif
 #ifdef HAVE_BZIP2
@@ -829,7 +828,7 @@ void add_compress_methods(unsigned char **s, int *l)
 		add_to_str(s, l, cast_uchar "BZIP2");
 		add_to_str(s, l, cast_uchar " (");
 		add_bytes_to_str(s, l, b, bl);
-		add_to_str(s, l, cast_uchar ")");
+		add_chr_to_str(s, l, ')');
 	}
 #endif
 #ifdef HAVE_LZMA
@@ -838,7 +837,7 @@ void add_compress_methods(unsigned char **s, int *l)
 		add_to_str(s, l, cast_uchar "LZMA");
 		add_to_str(s, l, cast_uchar " (");
 		add_to_str(s, l, cast_uchar lzma_version_string());
-		add_to_str(s, l, cast_uchar ")");
+		add_chr_to_str(s, l, ')');
 	}
 #endif
 #ifdef HAVE_LZIP
@@ -847,7 +846,7 @@ void add_compress_methods(unsigned char **s, int *l)
 		add_to_str(s, l, cast_uchar "LZIP");
 		add_to_str(s, l, cast_uchar " (");
 		add_to_str(s, l, cast_uchar LZ_version());
-		add_to_str(s, l, cast_uchar ")");
+		add_chr_to_str(s, l, ')');
 	}
 #endif
 }
