@@ -80,16 +80,6 @@ static struct graphics_driver *graphics_drivers[] = {
 	NULL
 };
 
-int dummy_block(struct graphics_device *dev)
-{
-	return 0;
-}
-
-int dummy_unblock(struct graphics_device *dev)
-{
-	return 0;
-}
-
 #if 0
 static unsigned char *list_graphics_drivers(void)
 {
@@ -97,7 +87,7 @@ static unsigned char *list_graphics_drivers(void)
 	int l = 0;
 	struct graphics_driver **gd;
 	for (gd = graphics_drivers; *gd; gd++) {
-		if (l) add_to_str(&d, &l, cast_uchar " ");
+		if (l) add_chr_to_str(&d, &l, ' ');
 		add_to_str(&d, &l, (*gd)->name);
 	}
 	return d;
@@ -294,10 +284,10 @@ void exclude_rect_from_set(struct rect_set **s, struct rect *r)
 			intersect_rect(&r3, &r3, rr);
 			rr->x1 = rr->x2 = rr->y1 = rr->y2 = 0;
 #ifdef DEBUG
-			if (is_rect_valid(&r1) && do_rects_intersect(&r1, r)) internal("bad intersection 1");
-			if (is_rect_valid(&r2) && do_rects_intersect(&r2, r)) internal("bad intersection 2");
-			if (is_rect_valid(&r3) && do_rects_intersect(&r3, r)) internal("bad intersection 3");
-			if (is_rect_valid(&r4) && do_rects_intersect(&r4, r)) internal("bad intersection 4");
+			if (is_rect_valid(&r1) && do_rects_intersect(&r1, r)) internal_error("bad intersection 1");
+			if (is_rect_valid(&r2) && do_rects_intersect(&r2, r)) internal_error("bad intersection 2");
+			if (is_rect_valid(&r3) && do_rects_intersect(&r3, r)) internal_error("bad intersection 3");
+			if (is_rect_valid(&r4) && do_rects_intersect(&r4, r)) internal_error("bad intersection 4");
 #endif
 			add_to_rect_set(s, &r1);
 			add_to_rect_set(s, &r2);
@@ -384,7 +374,7 @@ static struct timer *virtual_device_timer;
 void init_virtual_devices(struct graphics_driver *drv, int n)
 {
 	if (n_virtual_devices) {
-		internal("init_virtual_devices: already initialized");
+		internal_error("init_virtual_devices: already initialized");
 		return;
 	}
 	if ((unsigned)n > MAXINT / sizeof(struct graphics_device *)) overalloc();
@@ -457,7 +447,7 @@ void shutdown_virtual_device(struct graphics_device *dev)
 		return;
 	}
 	mem_free(dev);
-	/*internal("shutdown_virtual_device: device not initialized");*/
+	/*internal_error("shutdown_virtual_device: device not initialized");*/
 }
 
 void resize_virtual_devices(int x, int y)
@@ -479,10 +469,10 @@ void shutdown_virtual_devices(void)
 {
 	int i;
 	if (!n_virtual_devices) {
-		internal("shutdown_virtual_devices: already shut down");
+		internal_error("shutdown_virtual_devices: already shut down");
 		return;
 	}
-	for (i = 0; i < n_virtual_devices; i++) if (virtual_devices[i]) internal("shutdown_virtual_devices: virtual device %d is still active", i);
+	for (i = 0; i < n_virtual_devices; i++) if (virtual_devices[i]) internal_error("shutdown_virtual_devices: virtual device %d is still active", i);
 	mem_free(virtual_devices);
 	n_virtual_devices = 0;
 	if (virtual_device_timer != NULL) kill_timer(virtual_device_timer), virtual_device_timer = NULL;
