@@ -70,11 +70,11 @@ static void exit_heap(void)
 {
 #if DEBUGLEVEL >= 1
 	if (!HeapValidate(heap, 0, NULL))
-		internal("HeapValidate failed: %x", (unsigned)GetLastError());
+		internal_error("HeapValidate failed: %x", (unsigned)GetLastError());
 #endif
 #ifdef NEW_HEAP
 	if (!HeapDestroy(heap))
-		internal("HeapDestroy failed: %x", (unsigned)GetLastError());
+		internal_error("HeapDestroy failed: %x", (unsigned)GetLastError());
 #endif
 }
 
@@ -674,7 +674,7 @@ void mem_free(void *p)
 	dos_poll_break();
 	if (p == DUMMY) return;
 	if (!p) {
-		internal("mem_free(NULL)");
+		internal_error("mem_free(NULL)");
 		return;
 	}
 	heap_free(p);
@@ -687,7 +687,7 @@ void *mem_realloc_(void *p, size_t size, int mayfail)
 	dos_poll_break();
 	debug_test_free(NULL, 0);
 	if (!p) {
-		internal("mem_realloc(NULL, %lu)", (unsigned long)size);
+		internal_error("mem_realloc(NULL, %lu)", (unsigned long)size);
 		return NULL;
 	}
 	if (!size) {
