@@ -1404,10 +1404,10 @@ static void setup_functions(void)
 	}else do_sync=0;
 
 	svga_driver.get_color = get_color_fn(svga_driver.depth);
-	if (!svga_driver.get_color) internal("Unknown bit depth %x", svga_driver.depth);
+	if (!svga_driver.get_color) internal_error("Unknown bit depth %x", svga_driver.depth);
 	switch (vga_colors) {
 		case 2:
-		internal("2-color modes are not supported by links as they are buggy in svgalib and incapable of colors");
+		internal_error("2-color modes are not supported by links as they are buggy in svgalib and incapable of colors");
 
 		case 16:
 		alloc_scroll_buffer();
@@ -1927,8 +1927,8 @@ static inline void place_mouse_composite(void)
 			mouse_drawscansegment(mouse_ptr,mouse_left,mouse_top,l1);
 			if (background_length>0)
 				mouse_drawscansegment(
-					background_ptr +l2,
-					mouse_right,mouse_top ,l3);
+					background_ptr + l2,
+					mouse_right,mouse_top, l3);
 			mouse_ptr+=skip;
 			background_ptr+=skip;
 		}
@@ -2027,7 +2027,7 @@ static void vga_update_palette(void)
 		svga_driver.depth &= ~0x300;
 
 	svga_driver.get_color = get_color_fn(svga_driver.depth);
-	if (!svga_driver.get_color) internal("Unknown bit depth %x", svga_driver.depth);
+	if (!svga_driver.get_color) internal_error("Unknown bit depth %x", svga_driver.depth);
 
 	mouse_black = svga_driver.get_color(0);
 	mouse_white = svga_driver.get_color(0xffffff);
@@ -2288,7 +2288,7 @@ static int vga_unblock(struct graphics_device *dev)
 {
 #ifdef DEBUG
 	if (!(flags & 2)) {
-		internal("vga_unblock called without vga_block");
+		internal_error("vga_unblock called without vga_block");
 		return 0;
 	}
 #endif /* #ifdef DEBUG */
