@@ -58,7 +58,7 @@ static toff_t tiff_size(thandle_t data)
 	struct cached_image *cimg=(struct cached_image *)data;
 	struct tiff_decoder *deco=(struct tiff_decoder*)cimg->decoder;
 
-	if (!deco->tiff_open)internal("BUG IN LIBTIFF: sizeproc called on closed file. Contact the libtiff authors.\n");
+	if (!deco->tiff_open)internal_error("BUG IN LIBTIFF: sizeproc called on closed file. Contact the libtiff authors.\n");
 
 	return deco->tiff_size;
 }
@@ -69,7 +69,7 @@ static tsize_t tiff_read(thandle_t data, tdata_t dest, tsize_t count)
 	struct cached_image *cimg=(struct cached_image *)data;
 	struct tiff_decoder *deco=(struct tiff_decoder*)cimg->decoder;
 
-	if (!deco->tiff_open)internal("BUG IN LIBTIFF: readproc called on closed file. Contact the libtiff authors.\n");
+	if (!deco->tiff_open)internal_error("BUG IN LIBTIFF: readproc called on closed file. Contact the libtiff authors.\n");
 
 	if (count < 0)
 		return 0;
@@ -84,7 +84,7 @@ static tsize_t tiff_read(thandle_t data, tdata_t dest, tsize_t count)
 
 static tsize_t tiff_write(thandle_t data, tdata_t dest, tsize_t count)
 {
-	internal("BUG IN LIBTIFF: writeproc called on read-only file. Contact the libtiff authors.\n");
+	internal_error("BUG IN LIBTIFF: writeproc called on read-only file. Contact the libtiff authors.\n");
 	return 0;
 }
 
@@ -95,7 +95,7 @@ static toff_t tiff_seek(thandle_t data, toff_t offset, int whence)
 	struct tiff_decoder *deco=(struct tiff_decoder*)cimg->decoder;
 	long pos;
 
-	if (!deco->tiff_open)internal("BUG IN LIBTIFF: seekproc called on closed file. Contact the libtiff authors.\n");
+	if (!deco->tiff_open)internal_error("BUG IN LIBTIFF: seekproc called on closed file. Contact the libtiff authors.\n");
 
 	switch(whence)
 	{
@@ -124,7 +124,7 @@ static int tiff_close(void *data)
 	struct cached_image *cimg=(struct cached_image *)data;
 	struct tiff_decoder *deco=(struct tiff_decoder*)cimg->decoder;
 
-	if (!deco->tiff_open)internal("BUG IN LIBTIFF: closeproc called on closed file. Contact the libtiff authors.\n");
+	if (!deco->tiff_open)internal_error("BUG IN LIBTIFF: closeproc called on closed file. Contact the libtiff authors.\n");
 	tiff_destroy_decoder(cimg);
 	return 0;
 }
@@ -135,7 +135,7 @@ static int tiff_mmap(thandle_t data, tdata_t *dest, toff_t *len)
 	struct cached_image *cimg=(struct cached_image *)data;
 	struct tiff_decoder *deco=(struct tiff_decoder*)cimg->decoder;
 
-	if (!deco->tiff_open)internal("BUG IN LIBTIFF: mapproc called on closed file. Contact the libtiff authors.\n");
+	if (!deco->tiff_open)internal_error("BUG IN LIBTIFF: mapproc called on closed file. Contact the libtiff authors.\n");
 	*dest=deco->tiff_data;
 	*len=deco->tiff_size;
 	return 0;
@@ -147,7 +147,7 @@ static void tiff_munmap(thandle_t data, tdata_t dest, toff_t len)
 	struct cached_image *cimg=(struct cached_image *)data;
 	struct tiff_decoder *deco=(struct tiff_decoder*)cimg->decoder;
 
-	if (!deco->tiff_open)internal("BUG IN LIBTIFF: unmapproc called on closed file. Contact the libtiff authors.\n");
+	if (!deco->tiff_open)internal_error("BUG IN LIBTIFF: unmapproc called on closed file. Contact the libtiff authors.\n");
 }
 
 
@@ -278,7 +278,7 @@ void add_tiff_version(unsigned char **s, int *l)
 	if (pp) p = pp + 8;
 	pl = (int)strcspn(cast_const_char p, " \n");
 	add_bytes_to_str(s, l, p, pl);
-	add_to_str(s, l, cast_uchar ")");
+	add_chr_to_str(s, l, ')');
 }
 
 #endif /* #ifdef HAVE_TIFF */
