@@ -520,7 +520,7 @@ unsigned char *join_urls(unsigned char *base, unsigned char *rel)
 		if (!(s = cast_uchar strstr(cast_const_char base, "//"))) {
 			if (!(s = cast_uchar strchr(cast_const_char base, ':'))) {
 				bad_base:
-				internal("bad base url: %s", base);
+				internal_error("bad base url: %s", base);
 				return NULL;
 			}
 			s++;
@@ -1153,6 +1153,8 @@ static unsigned char *display_url_or_host(struct terminal *term, unsigned char *
 		url_enc = idn_encode_url(url_conv2, 0);
 	else
 		url_enc = idn_encode_host(url_conv2, (int)strlen(cast_const_char url_conv2), separator, 0);
+	if (!url_enc)
+		url_enc = stracpy(url_conv2), is_idn = 1;
 	mem_free(url_conv2);
 	if (!strcmp(cast_const_char url_enc, cast_const_char url)) {
 		if (is_idn && warn_idn) {
